@@ -15,20 +15,26 @@
 
 import abc
 
-from sushy_tools.emulator.resources.base import DriverBase
 
-
-class AbstractSystemsDriver(DriverBase, metaclass=abc.ABCMeta):
+class AbstractSystemsDriver(metaclass=abc.ABCMeta):
     """Base class for all virtualization drivers"""
 
-    @abc.abstractproperty
+    @classmethod
+    def initialize(cls, config, logger, *args, **kwargs):
+        """Initialize class attribute."""
+        cls._config = config
+        cls._logger = logger
+
+    @property
+    @abc.abstractmethod
     def driver(self):
         """Return human-friendly driver information
 
         :returns: driver information as `str`
         """
 
-    @abc.abstractproperty
+    @property
+    @abc.abstractmethod
     def systems(self):
         """Return available computer systems
 
