@@ -13,6 +13,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import collections
 import os
 import re
 import tempfile
@@ -25,6 +26,12 @@ from sushy_tools.emulator.resources import base
 from sushy_tools import error
 
 
+DeviceInfo = collections.namedtuple(
+    'DeviceInfo',
+    ['image_name', 'image_url', 'inserted', 'write_protected',
+     'username', 'password', 'verify'])
+
+
 class StaticDriver(base.DriverBase):
     """Redfish virtual media simulator."""
 
@@ -69,7 +76,7 @@ class StaticDriver(base.DriverBase):
             return self._devices[(identity, device)]
 
         except KeyError:
-            raise error.FishyError(
+            raise error.NotFound(
                 'No such virtual media device %s owned by resource '
                 '%s' % (device, identity))
 
@@ -116,19 +123,60 @@ class StaticDriver(base.DriverBase):
 
         :param identity: parent resource ID
         :param device: device name
-        :returns: a `tuple` of: image name, image path, `True` is media is
-            inserted, `True` if media is write-protected
+        :returns: a `DeviceInfo` with: image name, image path,
+            `True` is media is inserted, `True` if media is write-protected,
+            user name and password
         :raises: `error.FishyError`
         """
         device_info = self._get_device(identity, device)
 
-        return (device_info.get('ImageName', ''),
-                device_info.get('Image', ''),
-                device_info.get('Inserted', False),
-                device_info.get('WriteProtected', False))
+        return DeviceInfo(device_info.get('ImageName', ''),
+                          device_info.get('Image', ''),
+                          device_info.get('Inserted', False),
+                          device_info.get('WriteProtected', False),
+                          device_info.get('UserName', ''),
+                          device_info.get('Password', ''),
+                          device_info.get('Verify', False))
+
+    def update_device_info(self, identity, device, verify=False):
+        """Update the virtual media device
+
+        :param identity: parent resource ID
+        :param device: device name
+        :param verify: new value for VerifyCertificate
+        :raises: `error.FishyError`
+        """
+        device_info = self._get_device(identity, device)
+        device_info['Verify'] = verify
+        self._devices[(identity, device)] = device_info
+
+    def _write_from_response(self, image_url, rsp, tmp_file):
+        with open(tmp_file.name, 'wb') as fl:
+            for chunk in rsp.iter_content(chunk_size=8192):
+                if chunk:
+                    fl.write(chunk)
+
+        local_file = None
+
+        content_dsp = rsp.headers.get('content-disposition')
+        if content_dsp:
+            local_file = re.findall('filename="(.+)"', content_dsp)
+
+        if local_file:
+            local_file = local_file[0]
+
+        if not local_file:
+            parsed_url = urlparse.urlparse(image_url)
+            local_file = os.path.basename(parsed_url.path)
+
+        if not local_file:
+            local_file = 'image.iso'
+
+        return local_file
 
     def insert_image(self, identity, device, image_url,
-                     inserted=True, write_protected=True):
+                     inserted=True, write_protected=True,
+                     username=None, password=None):
         """Upload, remove or insert virtual media
 
         :param identity: parent resource ID
@@ -140,46 +188,43 @@ class StaticDriver(base.DriverBase):
         :raises: `FishyError` if image can't be manipulated
         """
         device_info = self._get_device(identity, device)
-        verify_media_cert = self._config.get(
-            'SUSHY_EMULATOR_VMEDIA_VERIFY_SSL', True)
+        verify_media_cert = device_info.get(
+            'Verify',
+            # NOTE(dtantsur): it's de facto standard for Redfish to default
+            # to no certificate validation.
+            self._config.get('SUSHY_EMULATOR_VMEDIA_VERIFY_SSL', False))
+        auth = (username, password) if (username and password) else None
 
         try:
-            with tempfile.NamedTemporaryFile(
-                    mode='w+b', delete=False) as tmp_file:
+            with requests.get(image_url,
+                              stream=True,
+                              auth=auth,
+                              verify=verify_media_cert) as rsp:
+                if rsp.status_code >= 400:
+                    self._logger.error(
+                        'Failed fetching image from URL %s: '
+                        'got HTTP error %s:\n%s',
+                        image_url, rsp.status_code, rsp.text)
+                    target_code = 502 if rsp.status_code >= 500 else 400
+                    raise error.FishyError(
+                        "Cannot download virtual media: got error %s "
+                        "from the server" % rsp.status_code,
+                        code=target_code)
 
-                with requests.get(image_url,
-                                  stream=True,
-                                  verify=verify_media_cert) as rsp:
-
-                    with open(tmp_file.name, 'wb') as fl:
-
-                        for chunk in rsp.iter_content(chunk_size=8192):
-                            if chunk:
-                                fl.write(chunk)
-
-                    local_file = None
-
-                    content_dsp = rsp.headers.get('content-disposition')
-                    if content_dsp:
-                        local_file = re.findall('filename="(.+)"', content_dsp)
-
-                    if local_file:
-                        local_file = local_file[0]
-
-                    if not local_file:
-                        parsed_url = urlparse.urlparse(image_url)
-                        local_file = os.path.basename(parsed_url.path)
-
-                    if not local_file:
-                        local_file = 'image.iso'
+                with tempfile.NamedTemporaryFile(
+                        mode='w+b', delete=False) as tmp_file:
 
+                    local_file = self._write_from_response(image_url,
+                                                           rsp, tmp_file)
                     temp_dir = tempfile.mkdtemp(
                         dir=os.path.dirname(tmp_file.name))
-
                     local_file_path = os.path.join(temp_dir, local_file)
 
                 os.rename(tmp_file.name, local_file_path)
-
+        except error.FishyError as ex:
+            msg = 'Failed fetching image from URL %s: %s' % (image_url, ex)
+            self._logger.error(msg)
+            raise  # leave the original error intact (code, etc)
         except Exception as ex:
             msg = 'Failed fetching image from URL %s: %s' % (image_url, ex)
             self._logger.exception(msg)
@@ -192,6 +237,8 @@ class StaticDriver(base.DriverBase):
         device_info['Image'] = local_file
         device_info['Inserted'] = inserted
         device_info['WriteProtected'] = write_protected
+        device_info['UserName'] = username or ''
+        device_info['Password'] = password or ''
         device_info['_local_file'] = local_file_path
 
         self._devices.update({(identity, device): device_info})
@@ -211,6 +258,8 @@ class StaticDriver(base.DriverBase):
         device_info['ImageName'] = ''
         device_info['Inserted'] = False
         device_info['WriteProtected'] = False
+        device_info['UserName'] = ''
+        device_info['Password'] = ''
 
         self._devices.update({(identity, device): device_info})
 
