@@ -17,6 +17,10 @@
 class FishyError(Exception):
     """Create generic sushy-tools exception object"""
 
+    def __init__(self, msg='Unknown error', code=500):
+        super().__init__(msg)
+        self.code = code
+
 
 class AliasAccessError(FishyError):
     """Node access attempted via an alias, not UUID"""
@@ -24,3 +28,17 @@ class AliasAccessError(FishyError):
 
 class NotSupportedError(FishyError):
     """Feature not supported by resource driver"""
+
+
+class NotFound(FishyError):
+    """Entity not found."""
+
+    def __init__(self, msg='Not found', code=404):
+        super().__init__(msg, code)
+
+
+class BadRequest(FishyError):
+    """Malformed request."""
+
+    def __init__(self, msg, code=400):
+        super().__init__(msg, code)
